@@ -22,7 +22,7 @@ extract_using_fallback_to_snapshot_no_cache = tldextract.TLDExtract(
 # pylint: enable=invalid-name
 
 
-def assert_extract(
+def assert_extract(  # pylint: disable=missing-docstring
         url,
         expected_domain_data,
         expected_ip_data='',
@@ -71,6 +71,11 @@ def test_odd_but_possible():
     assert_extract('http://www.com', ('www.com', '', 'www', 'com'))
 
 
+def test_suffix():
+    assert_extract('com', ('', '', '', 'com'))
+    assert_extract('co.uk', ('', '', '', 'co.uk'))
+
+
 def test_local_host():
     assert_extract('http://internalunlikelyhostname/',
                    ('', '', 'internalunlikelyhostname', ''))
@@ -122,6 +127,9 @@ def test_invalid_puny_with_puny():
     assert_extract('http://xn--zckzap6140b352by.blog.so-net.xn--wcvs22d.hk',
                    ('xn--zckzap6140b352by.blog.so-net.xn--wcvs22d.hk',
                     'xn--zckzap6140b352by.blog', 'so-net', 'xn--wcvs22d.hk'))
+    assert_extract('http://xn--&.so-net.com',
+                   ('xn--&.so-net.com',
+                    'xn--&', 'so-net', 'com'))
 
 
 def test_puny_with_non_puny():
